qpimage
=======

|PyPI Version| |Tests Status| |Coverage Status| |Docs Status|


**qpimage** is a Python3 library for manipulating quantitative phase images.


Documentation
-------------

The documentation, including the code reference and examples, is available at
`qpimage.readthedocs.io <https://qpimage.readthedocs.io/en/stable/>`__.


Installation
------------

::

    pip install qpimage


Testing
-------

::

    pip install pytest
    pip install -e .
    pytest tests


.. |PyPI Version| image:: https://img.shields.io/pypi/v/qpimage.svg
   :target: https://pypi.python.org/pypi/qpimage
.. |Tests Status| image:: https://img.shields.io/github/workflow/status/RI-Imaging/qpimage/Checks
   :target: https://github.com/RI-Imaging/qpimage/actions?query=workflow%3AChecks
.. |Coverage Status| image:: https://img.shields.io/codecov/c/github/RI-imaging/qpimage/master.svg
   :target: https://codecov.io/gh/RI-imaging/qpimage
.. |Docs Status| image:: https://readthedocs.org/projects/qpimage/badge/?version=latest
   :target: https://readthedocs.org/projects/qpimage/builds/

